@@ -16,7 +16,10 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>. *
  **************************************************************************/
 #include <iostream>
-
+#include <QtGui>
+#include <QtGui/QX11Info>
+#include <X11/Xlib.h>
+#include <X11/Xatom.h>
 #include <QtGui/QApplication>
 #include <qfiledialog.h>
 #include <qtimer.h>
@@ -132,6 +135,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags flags)
   connect( nextPage_,SIGNAL(clicked()), this, SLOT(doNextPage()) );
 
   setCentralWidget(pageView_);
+  grabZoomKeys();
 }
 
 MainWindow::~MainWindow()
@@ -145,6 +149,51 @@ MainWindow::~MainWindow()
   delete prevPage_;
 }
 
+void MainWindow::grabZoomKeys(bool grab)
+{
+  if (!winId()) {
+    qWarning("Can't grab keys unless we have a window id");
+    exit(1);
+    return;
+  }
+
+  unsigned long val = (grab) ? 1 : 0;
+  Atom atom = XInternAtom(QX11Info::display(), "_HILDON_ZOOM_KEY_ATOM", False);
+  if (!atom) {
+    qWarning("Unable to obtain _HILDON_ZOOM_KEY_ATOM. This example will only work "
+        "on a Maemo 5 device!");
+    return;
+  }
+
+  XChangeProperty (QX11Info::display(),
+      winId(),
+      atom,
+      XA_INTEGER,
+      32,
+      PropModeReplace,
+      reinterpret_cast<unsigned char *>(&val),
+      1);
+}
+
+
+void MainWindow::keyPressEvent(QKeyEvent* event)
+{
+  switch (event->key()) {
+    case Qt::Key_F7:
+      doZoomIn();
+      event->accept();
+      break;
+
+    case Qt::Key_F8:
+      doZoomOut();
+      event->accept();
+      break;
+  }
+  QWidget::keyPressEvent(event);
+}
+
+
+
 void MainWindow::openFile( const QString& fileName )
 {
   if (  pageView_->loadChmFile( fileName ) )
